@@ -1,17 +1,18 @@
 #!/usr/bin/perl
 
-use strict;
+use v5.26;
 use warnings;
 
 use Device::Chip::nRF24L01P;
 use Device::Chip::Adapter;
 
+use Future::AsyncAwait;
 use Getopt::Long;
 use Data::Dump 'pp';
 use Time::HiRes qw( sleep );
 
 GetOptions(
-   'adapter|A=s' => \( my $ADAPTER = "BusPirate" ),
+   'adapter|A=s' => \my $ADAPTER,
 
    'p|print-config' => \my $PRINT_CONFIG,
 
@@ -19,34 +20,35 @@ GetOptions(
 ) or exit 1;
 
 my $nrf = Device::Chip::nRF24L01P->new;
-$nrf->mount(
+await $nrf->mount(
    Device::Chip::Adapter->new_from_description( $ADAPTER )
-)->get;
+);
 
-$nrf->power(1)->get;
+await $nrf->power(1);
 print "Power on\n";
 
 if( $PRINT_CONFIG ) {
-   my $config = $nrf->read_config->get;
+   my $config = await $nrf->read_config;
    printf "%20s: %s\n", $_, $config->{$_} for sort keys %$config;
 }
 
 # Power-down to reconfigure
-$nrf->pwr_up( 0 )->get;
-$nrf->chip_enable( 0 )->get;
+await $nrf->pwr_up( 0 );
+await $nrf->chip_enable( 0 );
 
-$nrf->change_config(
+await $nrf->change_config(
    PRIM_RX => 1,
    RF_CH => $CHANNEL,
-)->get;
+);
 
 $nrf->clear_caches;
-printf "Config:\n%s\n%s\n", pp($nrf->read_config->get), pp($nrf->read_rx_config( 0 )->get);
+printf "Config:\n%s\n%s\n",
+   pp(await $nrf->read_config), pp(await $nrf->read_rx_config( 0 ));
 
-$nrf->pwr_up( 1 )->get;
+await $nrf->pwr_up( 1 );
 print "PWR_UP\n";
 
-$nrf->chip_enable( 1 )->get;
+await $nrf->chip_enable( 1 );
 print "CE high - entered PRX mode...\n";
 
 $SIG{INT} = $SIG{TERM} = sub { exit };
@@ -55,7 +57,7 @@ STDOUT->autoflush(1);
 
 while(1) {
    sleep 0.05;
-   my $rpd = $nrf->rpd->get;
+   my $rpd = await $nrf->rpd;
    print $rpd ? "X" : ".";
 }
 
